Index: components/test_runner/test_runner.h |
diff --git a/components/test_runner/test_runner.h b/components/test_runner/test_runner.h |
index 6b389b1417476b7ef7be9f020e0de8596547a4f9..b8f6284c647c9fc115f4e31938a89e6d1ab6f870 100644 |
--- a/components/test_runner/test_runner.h |
+++ b/components/test_runner/test_runner.h |
@@ -521,9 +521,25 @@ class TestRunner : public WebTestRunner, |
void SetColorProfile(const std::string& name, |
v8::Local<v8::Function> callback); |
// Change the bluetooth test data while running a layout test. |
void SetBluetoothMockDataSet(const std::string& name); |
+ // Makes the Bluetooth chooser record its input and wait for instructions from |
+ // the test program on how to proceed. |
+ void SetBluetoothManualChooser(); |
+ |
+ // Returns the events recorded since the last call to this function. |
+ std::vector<std::string> GetBluetoothManualChooserEvents(); |
+ |
+ // Calls the BluetoothChooser::EventHandler with the arguments here. Valid |
+ // event strings are: |
+ // * "cancel" - simulates the user canceling the chooser. |
+ // * "select" - simulates the user selecting a device whose device ID is in |
+ // |argument|. |
+ void SendBluetoothManualChooserEvent(const std::string& event, |
+ const std::string& argument); |
+ |
// Enables mock geofencing service while running a layout test. |
// |service_available| indicates if the mock service should mock geofencing |
// being available or not. |
@@ -521,9 +521,25 @@ class TestRunner : public WebTestRunner, |
void SetColorProfile(const std::string& name, |
v8::Local<v8::Function> callback); |
- // Change the bluetooth test data while running a layout test. |
+ // Change the bluetooth test data while running a layout test and resets the |
+ // chooser to accept the first device. |
void SetBluetoothMockDataSet(const std::string& name); |